==> qtjambi-quick-debuginfo-macos-5.15.20.jar: sources/QtJambiQuick/QSGGeometry_Attribute_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_Attribute(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::Attribute")
    QSGGeometry::Attribute *_ptr = reinterpret_cast<QSGGeometry::Attribute *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Attribute(QSGGeometry::Attribute)
void __qt_construct_QSGGeometry_Attribute_cref_QSGGeometry_Attribute(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Attribute(QSGGeometry::Attribute)")
    jobject other0 = __java_arguments[0].l;
    const QSGGeometry::Attribute& __qt_other0 = qtjambi_cast<const QSGGeometry::Attribute& >(__jni_env, other0);
    QSGGeometry::Attribute *__qt_this = new(__qtjambi_ptr) QSGGeometry::Attribute(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QSGGeometry::Attribute::Attribute(QSGGeometry::Attribute)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_initialize_1native__Lio_qt_quick_QSGGeometry_00024Attribute_2Lio_qt_quick_QSGGeometry_00024Attribute_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::Attribute::Attribute(QSGGeometry::Attribute)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_Attribute_cref_QSGGeometry_Attribute, sizeof(QSGGeometry::Attribute), typeid(QSGGeometry::Attribute), false, &deleter_QSGGeometry_Attribute, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Attribute{int,int,int,uint,QSGGeometry::AttributeType,uint}
void __qt_construct_QSGGeometry_Attribute_int_int_int_uint_QSGGeometry_AttributeType_uint(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Attribute{int,int,int,uint,QSGGeometry::AttributeType,uint}")
    jint position0 = __java_arguments[0].i;
    Q_UNUSED(position0)
    jint tupleSize1 = __java_arguments[1].i;
    Q_UNUSED(tupleSize1)
    jint type2 = __java_arguments[2].i;
    Q_UNUSED(type2)
    jboolean isVertexCoordinate3 = __java_arguments[3].z;
    Q_UNUSED(isVertexCoordinate3)
    jobject attributeType4 = __java_arguments[4].l;
    QSGGeometry::AttributeType __qt_attributeType4 = qtjambi_cast<QSGGeometry::AttributeType>(__jni_env, attributeType4);
    jint reserved5 = __java_arguments[5].i;
    Q_UNUSED(reserved5)
    QSGGeometry::Attribute *__qt_this = new(__qtjambi_ptr) QSGGeometry::Attribute{static_cast<int>(position0), static_cast<int>(tupleSize1), static_cast<int>(type2), static_cast<uint>(isVertexCoordinate3), QSGGeometry::AttributeType(__qt_attributeType4), static_cast<uint>(reserved5)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QSGGeometry::Attribute::Attribute{int,int,int,uint,QSGGeometry::AttributeType,uint}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_initialize_1native__Lio_qt_quick_QSGGeometry_00024Attribute_2IIIZLio_qt_quick_QSGGeometry_00024AttributeType_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint position0,
 jint tupleSize1,
 jint type2,
 jboolean isVertexCoordinate3,
 jobject attributeType4,
 jint reserved5)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::Attribute::Attribute{int,int,int,uint,QSGGeometry::AttributeType,uint}")
    QTJAMBI_TRY {
        jvalue arguments[6];
        arguments[0].i = position0;
        arguments[1].i = tupleSize1;
        arguments[2].i = type2;
        arguments[3].z = isVertexCoordinate3;
        arguments[4].l = attributeType4;
        arguments[5].i = reserved5;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_Attribute_int_int_int_uint_QSGGeometry_AttributeType_uint, sizeof(QSGGeometry::Attribute), typeid(QSGGeometry::Attribute), false, &deleter_QSGGeometry_Attribute, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGGeometry::Attribute
void __qt_destruct_QSGGeometry_Attribute(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::Attribute")
    reinterpret_cast<QSGGeometry::Attribute*>(ptr)->~Attribute();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::Attribute::operator==(QSGGeometry::Attribute,QSGGeometry::Attribute)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_equals_1native_1cref_1QSGGeometry_1Attribute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::Attribute::operator==(QSGGeometry::Attribute,QSGGeometry::Attribute)", __qt_this)
        const QSGGeometry::Attribute& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QSGGeometry::Attribute>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGGeometry::Attribute::create(int,int,int,bool)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_create__IIIZ)
(JNIEnv *__jni_env,
 jclass,
 jint pos0,
 jint tupleSize1,
 jint primitiveType2,
 jboolean isPosition3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::Attribute::create(int,int,int,bool)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::Attribute __qt_return_value = QSGGeometry::Attribute::create(static_cast<int>(pos0), static_cast<int>(tupleSize1), static_cast<int>(primitiveType2), static_cast<bool>(isPosition3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGGeometry::Attribute::createWithAttributeType(int,int,int,QSGGeometry::AttributeType)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_createWithAttributeType_1native_1int_1int_1int_1QSGGeometry_1AttributeType__IIII)
(JNIEnv *__jni_env,
 jclass,
 jint pos0,
 jint tupleSize1,
 jint primitiveType2,
 jint attributeType3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::Attribute::createWithAttributeType(int,int,int,QSGGeometry::AttributeType)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::AttributeType __qt_attributeType3 = qtjambi_cast<QSGGeometry::AttributeType>(__jni_env, attributeType3);
        QSGGeometry::Attribute __qt_return_value = QSGGeometry::Attribute::createWithAttributeType(static_cast<int>(pos0), static_cast<int>(tupleSize1), static_cast<int>(primitiveType2), QSGGeometry::AttributeType(__qt_attributeType3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_attributeType_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QSGGeometry::AttributeType&  __qt_value = __qt_this->attributeType;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_isVertexCoordinate_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        uint  __qt_value = __qt_this->isVertexCoordinate;
        __java_return_value = jboolean(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_position_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->position;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_tupleSize_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->tupleSize;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->type;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_Attribute(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::Attribute>("QSGGeometry::Attribute", "io/qt/quick/QSGGeometry$Attribute");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_Attribute, {
        ConstructorInfo(&__qt_construct_QSGGeometry_Attribute_cref_QSGGeometry_Attribute, "Lio/qt/quick/QSGGeometry$Attribute;")
       ,ConstructorInfo(&__qt_construct_QSGGeometry_Attribute_int_int_int_uint_QSGGeometry_AttributeType_uint, "IIIZLio/qt/quick/QSGGeometry$AttributeType;I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_Attribute);
    registerMetaType<QSGGeometry::Attribute>("QSGGeometry::Attribute");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-6.6.0.jar: sources/QtJambiQuick/QSGGeometry_Attribute_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_Attribute(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::Attribute")
    QSGGeometry::Attribute *_ptr = reinterpret_cast<QSGGeometry::Attribute *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// destruct QSGGeometry::Attribute
void __qt_destruct_QSGGeometry_Attribute(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::Attribute")
    reinterpret_cast<QSGGeometry::Attribute*>(ptr)->~Attribute();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::Attribute::operator==(QSGGeometry::Attribute,QSGGeometry::Attribute)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_operator_1equal_1native_1cref_1QSGGeometry_1Attribute__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::Attribute::operator==(QSGGeometry::Attribute,QSGGeometry::Attribute)", __qt_this)
        const QSGGeometry::Attribute& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QSGGeometry::Attribute>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGGeometry::Attribute::create(int,int,int,bool)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_create__IIIZ)
(JNIEnv *__jni_env,
 jclass,
 jint pos0,
 jint tupleSize1,
 jint primitiveType2,
 jboolean isPosition3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::Attribute::create(int,int,int,bool)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::Attribute __qt_return_value = QSGGeometry::Attribute::create(static_cast<int>(pos0), static_cast<int>(tupleSize1), static_cast<int>(primitiveType2), static_cast<bool>(isPosition3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGGeometry::Attribute::createWithAttributeType(int,int,int,QSGGeometry::AttributeType)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_createWithAttributeType_1native_1int_1int_1int_1QSGGeometry_1AttributeType__IIII)
(JNIEnv *__jni_env,
 jclass,
 jint pos0,
 jint tupleSize1,
 jint primitiveType2,
 jint attributeType3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::Attribute::createWithAttributeType(int,int,int,QSGGeometry::AttributeType)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::AttributeType __qt_attributeType3 = qtjambi_cast<QSGGeometry::AttributeType>(__jni_env, attributeType3);
        QSGGeometry::Attribute __qt_return_value = QSGGeometry::Attribute::createWithAttributeType(static_cast<int>(pos0), static_cast<int>(tupleSize1), static_cast<int>(primitiveType2), QSGGeometry::AttributeType(__qt_attributeType3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_attributeType_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QSGGeometry::AttributeType&  __qt_value = __qt_this->attributeType;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_isVertexCoordinate_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        uint  __qt_value = __qt_this->isVertexCoordinate;
        __java_return_value = jboolean(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_position_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->position;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_tupleSize_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->tupleSize;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->type;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024Attribute_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::Attribute *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::Attribute>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_Attribute(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::Attribute>("QSGGeometry::Attribute", "io/qt/quick/QSGGeometry$Attribute");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_Attribute, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_Attribute);
    registerMetaType<QSGGeometry::Attribute>("QSGGeometry::Attribute");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
